ui

package
v0.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 19, 2025 License: MIT Imports: 9 Imported by: 0

Documentation

Overview

Package ui handles rendering data on terminal screen powered by bubbletea project

Index

Constants

This section is empty.

Variables

var ErrorFetchingSprintKeybindings = []common.Keybinding{
	{
		Key:         "r",
		Description: "Refetch sprint tasks",
		ShortDesc:   "Refresh",
	},
	{
		Key:         "q/esc",
		Description: "Quit",
		ShortDesc:   "Quit",
	},
}

Functions

func Render

func Render() error

Types

type FocusState

type FocusState int
const (
	FocusProjects FocusState = iota
	FocusBoards
	FocusSprints
	FocusActiveSprint
)

Directories

Path Synopsis
Package common defines common functions, types, etc...
Package common defines common functions, types, etc...
Package sprint is responsible of fetching active sprint issues and display them in interactive way
Package sprint is responsible of fetching active sprint issues and display them in interactive way
tasksboard
Package tasksboard is reponsible for displaying tasks per developer
Package tasksboard is reponsible for displaying tasks per developer

Jump to