Documentation
¶
Overview ¶
Package ui handles rendering data on terminal screen powered by bubbletea project
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrorFetchingSprintKeybindings = []common.Keybinding{
{
Key: "r",
Description: "Refetch sprint tasks",
ShortDesc: "Refresh",
},
{
Key: "q/esc",
Description: "Quit",
ShortDesc: "Quit",
},
}
Functions ¶
Types ¶
type FocusState ¶
type FocusState int
const ( FocusProjects FocusState = iota FocusBoards FocusSprints FocusActiveSprint )
Directories
¶
| Path | Synopsis |
|---|---|
|
Package common defines common functions, types, etc...
|
Package common defines common functions, types, etc... |
|
Package sprint is responsible of fetching active sprint issues and display them in interactive way
|
Package sprint is responsible of fetching active sprint issues and display them in interactive way |
|
tasksboard
Package tasksboard is reponsible for displaying tasks per developer
|
Package tasksboard is reponsible for displaying tasks per developer |
Click to show internal directories.
Click to hide internal directories.